==> haskell-io-streams-haproxy-1.0.1.0-291-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-io-streams-haproxy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 io-streams-haproxy
version:              1.0.1.0
visibility:           public
id:                   io-streams-haproxy-1.0.1.0-CUgMXz21LcTGRznOrcunZB
key:                  io-streams-haproxy-1.0.1.0-CUgMXz21LcTGRznOrcunZB
license:              BSD-3-Clause
copyright:            (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer:           greg@gregorycollins.net
author:               Gregory Collins
homepage:             http://snapframework.com/
synopsis:             HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.

category:             Network, IO-Streams
abi:                  8df1559414c55bf80e1efcc5558b67c6
exposed:              True
exposed-modules:      System.IO.Streams.Network.HAProxy
hidden-modules:       System.IO.Streams.Network.Internal.Address
import-dirs:          /usr/lib/ghc-9.4.8/site-local/io-streams-haproxy-1.0.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/io-streams-haproxy-1.0.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/io-streams-haproxy-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-io-streams-haproxy
hs-libraries:         HSio-streams-haproxy-1.0.1.0-CUgMXz21LcTGRznOrcunZB
depends:
    attoparsec-0.14.4-GPSHKdrOxNAHtLNPx9PvVS base-4.17.2.1
    bytestring-0.11.5.3 io-streams-1.5.2.2-JhPRCNqNYhLFmYBmPutpnY
    network-3.1.4.0-HsnWpJCBJSkHDu8PyPRvYR transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock

haddock-html:         /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-io-streams-haproxy-1.0.1.0-292-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-io-streams-haproxy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 io-streams-haproxy
version:              1.0.1.0
visibility:           public
id:                   io-streams-haproxy-1.0.1.0-2xhaABqdoC7Je9fJJIg2eD
key:                  io-streams-haproxy-1.0.1.0-2xhaABqdoC7Je9fJJIg2eD
license:              BSD-3-Clause
copyright:            (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer:           greg@gregorycollins.net
author:               Gregory Collins
homepage:             http://snapframework.com/
synopsis:             HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.

category:             Network, IO-Streams
abi:                  3cae59c3e238b0776860d2ab0858885a
exposed:              True
exposed-modules:      System.IO.Streams.Network.HAProxy
hidden-modules:       System.IO.Streams.Network.Internal.Address
import-dirs:          /usr/lib/ghc-9.4.8/site-local/io-streams-haproxy-1.0.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/io-streams-haproxy-1.0.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/io-streams-haproxy-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-io-streams-haproxy
hs-libraries:         HSio-streams-haproxy-1.0.1.0-2xhaABqdoC7Je9fJJIg2eD
depends:
    attoparsec-0.14.4-21g0xvIiXNtBpdLdrKPYdv base-4.17.2.1
    bytestring-0.11.5.3 io-streams-1.5.2.2-GjT3I6xfddh2Lh2US4N804
    network-3.1.4.0-4LxzNodBXIzL8bUGme1k8m transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock

haddock-html:         /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
